# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class ClassificationType(enum.IntEnum):
    """
    Type of the classification problem.

    Attributes:
      CLASSIFICATION_TYPE_UNSPECIFIED (int): An un-set value of this enum.
      MULTICLASS (int): At most one label is allowed per example.
      MULTILABEL (int): Multiple labels are allowed for one example.
    """

    CLASSIFICATION_TYPE_UNSPECIFIED = 0
    MULTICLASS = 1
    MULTILABEL = 2


class Document(object):
    class Layout(object):
        class TextSegmentType(enum.IntEnum):
            """
            The type of TextSegment in the context of the original document.

            Attributes:
              TEXT_SEGMENT_TYPE_UNSPECIFIED (int): Should not be used.
              TOKEN (int): The text segment is a token. e.g. word.
              PARAGRAPH (int): The text segment is a paragraph.
              FORM_FIELD (int): The text segment is a form field.
              FORM_FIELD_NAME (int): The text segment is the name part of a form field. It will be treated as
              child of another FORM\_FIELD TextSegment if its span is subspan of
              another TextSegment with type FORM\_FIELD.
              FORM_FIELD_CONTENTS (int): The text segment is the text content part of a form field. It will be
              treated as child of another FORM\_FIELD TextSegment if its span is
              subspan of another TextSegment with type FORM\_FIELD.
              TABLE (int): The text segment is a whole table, including headers, and all rows.
              TABLE_HEADER (int): The text segment is a table's headers. It will be treated as child of
              another TABLE TextSegment if its span is subspan of another TextSegment
              with type TABLE.
              TABLE_ROW (int): The text segment is a row in table. It will be treated as child of
              another TABLE TextSegment if its span is subspan of another TextSegment
              with type TABLE.
              TABLE_CELL (int): The text segment is a cell in table. It will be treated as child of
              another TABLE\_ROW TextSegment if its span is subspan of another
              TextSegment with type TABLE\_ROW.
            """

            TEXT_SEGMENT_TYPE_UNSPECIFIED = 0
            TOKEN = 1
            PARAGRAPH = 2
            FORM_FIELD = 3
            FORM_FIELD_NAME = 4
            FORM_FIELD_CONTENTS = 5
            TABLE = 6
            TABLE_HEADER = 7
            TABLE_ROW = 8
            TABLE_CELL = 9


class DocumentDimensions(object):
    class DocumentDimensionUnit(enum.IntEnum):
        """
        Unit of the document dimension.

        Attributes:
          DOCUMENT_DIMENSION_UNIT_UNSPECIFIED (int): Should not be used.
          INCH (int): Document dimension is measured in inches.
          CENTIMETER (int): Document dimension is measured in centimeters.
          POINT (int): Document dimension is measured in points. 72 points = 1 inch.
        """

        DOCUMENT_DIMENSION_UNIT_UNSPECIFIED = 0
        INCH = 1
        CENTIMETER = 2
        POINT = 3


class Model(object):
    class DeploymentState(enum.IntEnum):
        """
        Deployment state of the model.

        Attributes:
          DEPLOYMENT_STATE_UNSPECIFIED (int): Should not be used, an un-set enum has this value by default.
          DEPLOYED (int): Model is deployed.
          UNDEPLOYED (int): Model is not deployed.
        """

        DEPLOYMENT_STATE_UNSPECIFIED = 0
        DEPLOYED = 1
        UNDEPLOYED = 2



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1/proto/dataset.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.automl_v1.proto import (
    image_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2,
)
from google.cloud.automl_v1.proto import (
    text_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2,
)
from google.cloud.automl_v1.proto import (
    translation_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_translation__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1/proto/dataset.proto",
    package="google.cloud.automl.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\032com.google.cloud.automl.v1P\001Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\252\002\026Google.Cloud.AutoML.V1\312\002\026Google\\Cloud\\AutoMl\\V1\352\002\031Google::Cloud::AutoML::V1"
    ),
    serialized_pb=_b(
        "\n*google/cloud/automl_v1/proto/dataset.proto\x12\x16google.cloud.automl.v1\x1a\x19google/api/resource.proto\x1a(google/cloud/automl_v1/proto/image.proto\x1a'google/cloud/automl_v1/proto/text.proto\x1a.google/cloud/automl_v1/proto/translation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\x80\x07\n\x07\x44\x61taset\x12Z\n\x1ctranslation_dataset_metadata\x18\x17 \x01(\x0b\x32\x32.google.cloud.automl.v1.TranslationDatasetMetadataH\x00\x12k\n%image_classification_dataset_metadata\x18\x18 \x01(\x0b\x32:.google.cloud.automl.v1.ImageClassificationDatasetMetadataH\x00\x12i\n$text_classification_dataset_metadata\x18\x19 \x01(\x0b\x32\x39.google.cloud.automl.v1.TextClassificationDatasetMetadataH\x00\x12n\n'image_object_detection_dataset_metadata\x18\x1a \x01(\x0b\x32;.google.cloud.automl.v1.ImageObjectDetectionDatasetMetadataH\x00\x12\x61\n text_extraction_dataset_metadata\x18\x1c \x01(\x0b\x32\x35.google.cloud.automl.v1.TextExtractionDatasetMetadataH\x00\x12_\n\x1ftext_sentiment_dataset_metadata\x18\x1e \x01(\x0b\x32\x34.google.cloud.automl.v1.TextSentimentDatasetMetadataH\x00\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rexample_count\x18\x15 \x01(\x05\x12/\n\x0b\x63reate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x65tag\x18\x11 \x01(\t\x12;\n\x06labels\x18' \x03(\x0b\x32+.google.cloud.automl.v1.Dataset.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x64\x61taset_metadataB\xaa\x01\n\x1a\x63om.google.cloud.automl.v1P\x01Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\xaa\x02\x16Google.Cloud.AutoML.V1\xca\x02\x16Google\\Cloud\\AutoMl\\V1\xea\x02\x19Google::Cloud::AutoML::V1b\x06proto3"
    ),
    dependencies=[
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_translation__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_DATASET_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="google.cloud.automl.v1.Dataset.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.Dataset.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.Dataset.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1123,
    serialized_end=1168,
)

_DATASET = _descriptor.Descriptor(
    name="Dataset",
    full_name="google.cloud.automl.v1.Dataset",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="translation_dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.translation_dataset_metadata",
            index=0,
            number=23,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_classification_dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.image_classification_dataset_metadata",
            index=1,
            number=24,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_classification_dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.text_classification_dataset_metadata",
            index=2,
            number=25,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_object_detection_dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.image_object_detection_dataset_metadata",
            index=3,
            number=26,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_extraction_dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.text_extraction_dataset_metadata",
            index=4,
            number=28,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_sentiment_dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.text_sentiment_dataset_metadata",
            index=5,
            number=30,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.Dataset.name",
            index=6,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.automl.v1.Dataset.display_name",
            index=7,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.automl.v1.Dataset.description",
            index=8,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="example_count",
            full_name="google.cloud.automl.v1.Dataset.example_count",
            index=9,
            number=21,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.automl.v1.Dataset.create_time",
            index=10,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="etag",
            full_name="google.cloud.automl.v1.Dataset.etag",
            index=11,
            number=17,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="google.cloud.automl.v1.Dataset.labels",
            index=12,
            number=39,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_DATASET_LABELSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="dataset_metadata",
            full_name="google.cloud.automl.v1.Dataset.dataset_metadata",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=292,
    serialized_end=1188,
)

_DATASET_LABELSENTRY.containing_type = _DATASET
_DATASET.fields_by_name[
    "translation_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_translation__pb2._TRANSLATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "image_classification_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2._IMAGECLASSIFICATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "text_classification_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2._TEXTCLASSIFICATIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "image_object_detection_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2._IMAGEOBJECTDETECTIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "text_extraction_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2._TEXTEXTRACTIONDATASETMETADATA
)
_DATASET.fields_by_name[
    "text_sentiment_dataset_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2._TEXTSENTIMENTDATASETMETADATA
)
_DATASET.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASET.fields_by_name["labels"].message_type = _DATASET_LABELSENTRY
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["translation_dataset_metadata"]
)
_DATASET.fields_by_name[
    "translation_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["image_classification_dataset_metadata"]
)
_DATASET.fields_by_name[
    "image_classification_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["text_classification_dataset_metadata"]
)
_DATASET.fields_by_name[
    "text_classification_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["image_object_detection_dataset_metadata"]
)
_DATASET.fields_by_name[
    "image_object_detection_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["text_extraction_dataset_metadata"]
)
_DATASET.fields_by_name[
    "text_extraction_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
_DATASET.oneofs_by_name["dataset_metadata"].fields.append(
    _DATASET.fields_by_name["text_sentiment_dataset_metadata"]
)
_DATASET.fields_by_name[
    "text_sentiment_dataset_metadata"
].containing_oneof = _DATASET.oneofs_by_name["dataset_metadata"]
DESCRIPTOR.message_types_by_name["Dataset"] = _DATASET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dataset = _reflection.GeneratedProtocolMessageType(
    "Dataset",
    (_message.Message,),
    dict(
        LabelsEntry=_reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_DATASET_LABELSENTRY,
                __module__="google.cloud.automl_v1.proto.dataset_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.Dataset.LabelsEntry)
            ),
        ),
        DESCRIPTOR=_DATASET,
        __module__="google.cloud.automl_v1.proto.dataset_pb2",
        __doc__="""A workspace for solving a single, particular machine
  learning (ML) problem. A workspace contains examples that may be
  annotated.
  
  
  Attributes:
      dataset_metadata:
          Required. The dataset metadata that is specific to the problem
          type.
      translation_dataset_metadata:
          Metadata for a dataset used for translation.
      image_classification_dataset_metadata:
          Metadata for a dataset used for image classification.
      text_classification_dataset_metadata:
          Metadata for a dataset used for text classification.
      image_object_detection_dataset_metadata:
          Metadata for a dataset used for image object detection.
      text_extraction_dataset_metadata:
          Metadata for a dataset used for text extraction.
      text_sentiment_dataset_metadata:
          Metadata for a dataset used for text sentiment.
      name:
          Output only. The resource name of the dataset. Form: ``project
          s/{project_id}/locations/{location_id}/datasets/{dataset_id}``
      display_name:
          Required. The name of the dataset to show in the interface.
          The name can be up to 32 characters long and can consist only
          of ASCII Latin letters A-Z and a-z, underscores (\_), and
          ASCII digits 0-9.
      description:
          User-provided description of the dataset. The description can
          be up to 25000 characters long.
      example_count:
          Output only. The number of examples in the dataset.
      create_time:
          Output only. Timestamp when this dataset was created.
      etag:
          Used to perform consistent read-modify-write updates. If not
          set, a blind "overwrite" update happens.
      labels:
          Optional. The labels with user-defined metadata to organize
          your dataset.  Label keys and values can be no longer than 64
          characters (Unicode codepoints), can only contain lowercase
          letters, numeric characters, underscores and dashes.
          International characters are allowed. Label values are
          optional. Label keys must start with a letter.  See
          https://goo.gl/xmQnxf for more information on and examples of
          labels.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.Dataset)
    ),
)
_sym_db.RegisterMessage(Dataset)
_sym_db.RegisterMessage(Dataset.LabelsEntry)


DESCRIPTOR._options = None
_DATASET_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1/proto/prediction_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.automl_v1.proto import (
    annotation_payload_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__payload__pb2,
)
from google.cloud.automl_v1.proto import (
    data_items_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_data__items__pb2,
)
from google.cloud.automl_v1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1.proto import (
    operations_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_operations__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1/proto/prediction_service.proto",
    package="google.cloud.automl.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\032com.google.cloud.automl.v1B\026PredictionServiceProtoP\001Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\252\002\026Google.Cloud.AutoML.V1\312\002\026Google\\Cloud\\AutoMl\\V1\352\002\031Google::Cloud::AutoML::V1"
    ),
    serialized_pb=_b(
        '\n5google/cloud/automl_v1/proto/prediction_service.proto\x12\x16google.cloud.automl.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x35google/cloud/automl_v1/proto/annotation_payload.proto\x1a-google/cloud/automl_v1/proto/data_items.proto\x1a%google/cloud/automl_v1/proto/io.proto\x1a-google/cloud/automl_v1/proto/operations.proto\x1a#google/longrunning/operations.proto"\xca\x01\n\x0ePredictRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x07payload\x18\x02 \x01(\x0b\x32&.google.cloud.automl.v1.ExamplePayload\x12\x42\n\x06params\x18\x03 \x03(\x0b\x32\x32.google.cloud.automl.v1.PredictRequest.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x8b\x02\n\x0fPredictResponse\x12:\n\x07payload\x18\x01 \x03(\x0b\x32).google.cloud.automl.v1.AnnotationPayload\x12\x42\n\x12preprocessed_input\x18\x03 \x01(\x0b\x32&.google.cloud.automl.v1.ExamplePayload\x12G\n\x08metadata\x18\x02 \x03(\x0b\x32\x35.google.cloud.automl.v1.PredictResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xab\x02\n\x13\x42\x61tchPredictRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x0cinput_config\x18\x03 \x01(\x0b\x32/.google.cloud.automl.v1.BatchPredictInputConfig\x12G\n\routput_config\x18\x04 \x01(\x0b\x32\x30.google.cloud.automl.v1.BatchPredictOutputConfig\x12G\n\x06params\x18\x05 \x03(\x0b\x32\x37.google.cloud.automl.v1.BatchPredictRequest.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x91\x01\n\x12\x42\x61tchPredictResult\x12J\n\x08metadata\x18\x01 \x03(\x0b\x32\x38.google.cloud.automl.v1.BatchPredictResult.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x9b\x03\n\x11PredictionService\x12\x99\x01\n\x07Predict\x12&.google.cloud.automl.v1.PredictRequest\x1a\'.google.cloud.automl.v1.PredictResponse"=\x82\xd3\xe4\x93\x02\x37"2/v1/{name=projects/*/locations/*/models/*}:predict:\x01*\x12\x9e\x01\n\x0c\x42\x61tchPredict\x12+.google.cloud.automl.v1.BatchPredictRequest\x1a\x1d.google.longrunning.Operation"B\x82\xd3\xe4\x93\x02<"7/v1/{name=projects/*/locations/*/models/*}:batchPredict:\x01*\x1aI\xca\x41\x15\x61utoml.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xc2\x01\n\x1a\x63om.google.cloud.automl.v1B\x16PredictionServiceProtoP\x01Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\xaa\x02\x16Google.Cloud.AutoML.V1\xca\x02\x16Google\\Cloud\\AutoMl\\V1\xea\x02\x19Google::Cloud::AutoML::V1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__payload__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_data__items__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_operations__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
    ],
)


_PREDICTREQUEST_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1.PredictRequest.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.PredictRequest.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.PredictRequest.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=546,
    serialized_end=591,
)

_PREDICTREQUEST = _descriptor.Descriptor(
    name="PredictRequest",
    full_name="google.cloud.automl.v1.PredictRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.PredictRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.automl.v1.PredictRequest.payload",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1.PredictRequest.params",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PREDICTREQUEST_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=389,
    serialized_end=591,
)


_PREDICTRESPONSE_METADATAENTRY = _descriptor.Descriptor(
    name="MetadataEntry",
    full_name="google.cloud.automl.v1.PredictResponse.MetadataEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.PredictResponse.MetadataEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.PredictResponse.MetadataEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=814,
    serialized_end=861,
)

_PREDICTRESPONSE = _descriptor.Descriptor(
    name="PredictResponse",
    full_name="google.cloud.automl.v1.PredictResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.automl.v1.PredictResponse.payload",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="preprocessed_input",
            full_name="google.cloud.automl.v1.PredictResponse.preprocessed_input",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.automl.v1.PredictResponse.metadata",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PREDICTRESPONSE_METADATAENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=594,
    serialized_end=861,
)


_BATCHPREDICTREQUEST_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1.BatchPredictRequest.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.BatchPredictRequest.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.BatchPredictRequest.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=546,
    serialized_end=591,
)

_BATCHPREDICTREQUEST = _descriptor.Descriptor(
    name="BatchPredictRequest",
    full_name="google.cloud.automl.v1.BatchPredictRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.BatchPredictRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1.BatchPredictRequest.input_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1.BatchPredictRequest.output_config",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1.BatchPredictRequest.params",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_BATCHPREDICTREQUEST_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=864,
    serialized_end=1163,
)


_BATCHPREDICTRESULT_METADATAENTRY = _descriptor.Descriptor(
    name="MetadataEntry",
    full_name="google.cloud.automl.v1.BatchPredictResult.MetadataEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.BatchPredictResult.MetadataEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.BatchPredictResult.MetadataEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=814,
    serialized_end=861,
)

_BATCHPREDICTRESULT = _descriptor.Descriptor(
    name="BatchPredictResult",
    full_name="google.cloud.automl.v1.BatchPredictResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.automl.v1.BatchPredictResult.metadata",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_BATCHPREDICTRESULT_METADATAENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1166,
    serialized_end=1311,
)

_PREDICTREQUEST_PARAMSENTRY.containing_type = _PREDICTREQUEST
_PREDICTREQUEST.fields_by_name[
    "payload"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_data__items__pb2._EXAMPLEPAYLOAD
)
_PREDICTREQUEST.fields_by_name["params"].message_type = _PREDICTREQUEST_PARAMSENTRY
_PREDICTRESPONSE_METADATAENTRY.containing_type = _PREDICTRESPONSE
_PREDICTRESPONSE.fields_by_name[
    "payload"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__payload__pb2._ANNOTATIONPAYLOAD
)
_PREDICTRESPONSE.fields_by_name[
    "preprocessed_input"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_data__items__pb2._EXAMPLEPAYLOAD
)
_PREDICTRESPONSE.fields_by_name[
    "metadata"
].message_type = _PREDICTRESPONSE_METADATAENTRY
_BATCHPREDICTREQUEST_PARAMSENTRY.containing_type = _BATCHPREDICTREQUEST
_BATCHPREDICTREQUEST.fields_by_name[
    "input_config"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2._BATCHPREDICTINPUTCONFIG
)
_BATCHPREDICTREQUEST.fields_by_name[
    "output_config"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2._BATCHPREDICTOUTPUTCONFIG
)
_BATCHPREDICTREQUEST.fields_by_name[
    "params"
].message_type = _BATCHPREDICTREQUEST_PARAMSENTRY
_BATCHPREDICTRESULT_METADATAENTRY.containing_type = _BATCHPREDICTRESULT
_BATCHPREDICTRESULT.fields_by_name[
    "metadata"
].message_type = _BATCHPREDICTRESULT_METADATAENTRY
DESCRIPTOR.message_types_by_name["PredictRequest"] = _PREDICTREQUEST
DESCRIPTOR.message_types_by_name["PredictResponse"] = _PREDICTRESPONSE
DESCRIPTOR.message_types_by_name["BatchPredictRequest"] = _BATCHPREDICTREQUEST
DESCRIPTOR.message_types_by_name["BatchPredictResult"] = _BATCHPREDICTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictRequest = _reflection.GeneratedProtocolMessageType(
    "PredictRequest",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PREDICTREQUEST_PARAMSENTRY,
                __module__="google.cloud.automl_v1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.PredictRequest.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_PREDICTREQUEST,
        __module__="google.cloud.automl_v1.proto.prediction_service_pb2",
        __doc__="""Request message for
  [PredictionService.Predict][google.cloud.automl.v1.PredictionService.Predict].
  
  
  Attributes:
      name:
          Name of the model requested to serve the prediction.
      payload:
          Required. Payload to perform a prediction on. The payload must
          match the problem type that the model was trained to solve.
      params:
          Additional domain-specific parameters, any string must be up
          to 25000 characters long.  -  For Image Classification:
          ``score_threshold`` - (float) A value from 0.0 to 1.0. When
          the model makes predictions for an image, it will only produce
          results that have at least this confidence score. The default
          is 0.5.  -  For Image Object Detection: ``score_threshold`` -
          (float) When Model    detects objects on the image, it will
          only produce bounding boxes    which have at least this
          confidence score. Value in 0 to 1 range,    default is 0.5.
          ``max_bounding_box_count`` - (int64) No more than    this
          number of bounding boxes will be returned in the response.
          Default is 100, the requested value may be limited by server.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.PredictRequest)
    ),
)
_sym_db.RegisterMessage(PredictRequest)
_sym_db.RegisterMessage(PredictRequest.ParamsEntry)

PredictResponse = _reflection.GeneratedProtocolMessageType(
    "PredictResponse",
    (_message.Message,),
    dict(
        MetadataEntry=_reflection.GeneratedProtocolMessageType(
            "MetadataEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PREDICTRESPONSE_METADATAENTRY,
                __module__="google.cloud.automl_v1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.PredictResponse.MetadataEntry)
            ),
        ),
        DESCRIPTOR=_PREDICTRESPONSE,
        __module__="google.cloud.automl_v1.proto.prediction_service_pb2",
        __doc__="""Response message for
  [PredictionService.Predict][google.cloud.automl.v1.PredictionService.Predict].
  
  
  Attributes:
      payload:
          Prediction result. Translation and Text Sentiment will return
          precisely one payload.
      preprocessed_input:
          The preprocessed example that AutoML actually makes prediction
          on. Empty if AutoML does not preprocess the input example. \*
          For Text Extraction: If the input is a .pdf file, the OCR'ed
          text will be provided in [document\_text][google.cloud.automl.
          v1.Document.document\_text].  -  For Text Classification: If
          the input is a .pdf file, the OCR'ed    trucated text will be
          provided in    [document\_text][google.cloud.automl.v1.Documen
          t.document\_text].  -  For Text Sentiment: If the input is a
          .pdf file, the OCR'ed trucated    text will be provided in    
          [document\_text][google.cloud.automl.v1.Document.document\_tex
          t].
      metadata:
          Additional domain-specific prediction response metadata.  -
          For Image Object Detection: ``max_bounding_box_count`` -
          (int64) At    most that many bounding boxes per image could
          have been returned.  -  For Text Sentiment:
          ``sentiment_score`` - (float, deprecated) A value    between
          -1 and 1, -1 maps to least positive sentiment, while 1 maps
          to the most positive one and the higher the score, the more
          positive    the sentiment in the document is. Yet these values
          are relative to    the training data, so e.g. if all data was
          positive then -1 will be    also positive (though the least).
          The sentiment\_score shouldn't be    confused with "score" or
          "magnitude" from the previous Natural    Language Sentiment
          Analysis API.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.PredictResponse)
    ),
)
_sym_db.RegisterMessage(PredictResponse)
_sym_db.RegisterMessage(PredictResponse.MetadataEntry)

BatchPredictRequest = _reflection.GeneratedProtocolMessageType(
    "BatchPredictRequest",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_BATCHPREDICTREQUEST_PARAMSENTRY,
                __module__="google.cloud.automl_v1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.BatchPredictRequest.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_BATCHPREDICTREQUEST,
        __module__="google.cloud.automl_v1.proto.prediction_service_pb2",
        __doc__="""Request message for
  [PredictionService.BatchPredict][google.cloud.automl.v1.PredictionService.BatchPredict].
  
  
  Attributes:
      name:
          Name of the model requested to serve the batch prediction.
      input_config:
          Required. The input configuration for batch prediction.
      output_config:
          Required. The Configuration specifying where output
          predictions should be written.
      params:
          Additional domain-specific parameters for the predictions, any
          string must be up to 25000 characters long.  -  For Text
          Classification:  ``score_threshold`` - (float) A value from
          0.0 to 1.0. When the model makes predictions for a text
          snippet, it will only produce results that have at least this
          confidence score. The default is 0.5.  -  For Image
          Classification:  ``score_threshold`` - (float) A value from
          0.0 to 1.0. When the model makes predictions for an image, it
          will only produce results that have at least this confidence
          score. The default is 0.5.  -  For Image Object Detection:
          ``score_threshold`` - (float) When Model detects objects on
          the image, it will only produce bounding boxes which have at
          least this confidence score. Value in 0 to 1 range, default is
          0.5. ``max_bounding_box_count`` - (int64) No more than this
          number of bounding boxes will be produced per image. Default
          is 100, the requested value may be limited by server.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.BatchPredictRequest)
    ),
)
_sym_db.RegisterMessage(BatchPredictRequest)
_sym_db.RegisterMessage(BatchPredictRequest.ParamsEntry)

BatchPredictResult = _reflection.GeneratedProtocolMessageType(
    "BatchPredictResult",
    (_message.Message,),
    dict(
        MetadataEntry=_reflection.GeneratedProtocolMessageType(
            "MetadataEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_BATCHPREDICTRESULT_METADATAENTRY,
                __module__="google.cloud.automl_v1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.BatchPredictResult.MetadataEntry)
            ),
        ),
        DESCRIPTOR=_BATCHPREDICTRESULT,
        __module__="google.cloud.automl_v1.proto.prediction_service_pb2",
        __doc__="""Result of the Batch Predict. This message is returned in
  [response][google.longrunning.Operation.response] of the operation
  returned by the
  [PredictionService.BatchPredict][google.cloud.automl.v1.PredictionService.BatchPredict].
  
  
  Attributes:
      metadata:
          Additional domain-specific prediction response metadata.  -
          For Image Object Detection: ``max_bounding_box_count`` -
          (int64) At    most that many bounding boxes per image could
          have been returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.BatchPredictResult)
    ),
)
_sym_db.RegisterMessage(BatchPredictResult)
_sym_db.RegisterMessage(BatchPredictResult.MetadataEntry)


DESCRIPTOR._options = None
_PREDICTREQUEST_PARAMSENTRY._options = None
_PREDICTRESPONSE_METADATAENTRY._options = None
_BATCHPREDICTREQUEST_PARAMSENTRY._options = None
_BATCHPREDICTRESULT_METADATAENTRY._options = None

_PREDICTIONSERVICE = _descriptor.ServiceDescriptor(
    name="PredictionService",
    full_name="google.cloud.automl.v1.PredictionService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\025automl.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform"
    ),
    serialized_start=1314,
    serialized_end=1725,
    methods=[
        _descriptor.MethodDescriptor(
            name="Predict",
            full_name="google.cloud.automl.v1.PredictionService.Predict",
            index=0,
            containing_service=None,
            input_type=_PREDICTREQUEST,
            output_type=_PREDICTRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\0027"2/v1/{name=projects/*/locations/*/models/*}:predict:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="BatchPredict",
            full_name="google.cloud.automl.v1.PredictionService.BatchPredict",
            index=1,
            containing_service=None,
            input_type=_BATCHPREDICTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002<"7/v1/{name=projects/*/locations/*/models/*}:batchPredict:\001*'
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_PREDICTIONSERVICE)

DESCRIPTOR.services_by_name["PredictionService"] = _PREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1/proto/io.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1/proto/io.proto",
    package="google.cloud.automl.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\032com.google.cloud.automl.v1P\001Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\252\002\026Google.Cloud.AutoML.V1\312\002\026Google\\Cloud\\AutoMl\\V1\352\002\031Google::Cloud::AutoML::V1"
    ),
    serialized_pb=_b(
        '\n%google/cloud/automl_v1/proto/io.proto\x12\x16google.cloud.automl.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto"\xc0\x01\n\x0bInputConfig\x12\x37\n\ngcs_source\x18\x01 \x01(\x0b\x32!.google.cloud.automl.v1.GcsSourceH\x00\x12?\n\x06params\x18\x02 \x03(\x0b\x32/.google.cloud.automl.v1.InputConfig.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source"a\n\x17\x42\x61tchPredictInputConfig\x12<\n\ngcs_source\x18\x01 \x01(\x0b\x32!.google.cloud.automl.v1.GcsSourceB\x03\xe0\x41\x02H\x00\x42\x08\n\x06source"L\n\x13\x44ocumentInputConfig\x12\x35\n\ngcs_source\x18\x01 \x01(\x0b\x32!.google.cloud.automl.v1.GcsSource"e\n\x0cOutputConfig\x12\x46\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1.GcsDestinationB\x03\xe0\x41\x02H\x00\x42\r\n\x0b\x64\x65stination"q\n\x18\x42\x61tchPredictOutputConfig\x12\x46\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1.GcsDestinationB\x03\xe0\x41\x02H\x00\x42\r\n\x0b\x64\x65stination"\x82\x02\n\x17ModelExportOutputConfig\x12\x46\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1.GcsDestinationB\x03\xe0\x41\x02H\x00\x12\x14\n\x0cmodel_format\x18\x04 \x01(\t\x12K\n\x06params\x18\x02 \x03(\x0b\x32;.google.cloud.automl.v1.ModelExportOutputConfig.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b\x64\x65stination"$\n\tGcsSource\x12\x17\n\ninput_uris\x18\x01 \x03(\tB\x03\xe0\x41\x02"0\n\x0eGcsDestination\x12\x1e\n\x11output_uri_prefix\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\xaa\x01\n\x1a\x63om.google.cloud.automl.v1P\x01Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\xaa\x02\x16Google.Cloud.AutoML.V1\xca\x02\x16Google\\Cloud\\AutoMl\\V1\xea\x02\x19Google::Cloud::AutoML::V1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
    ],
)


_INPUTCONFIG_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1.InputConfig.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.InputConfig.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.InputConfig.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=266,
    serialized_end=311,
)

_INPUTCONFIG = _descriptor.Descriptor(
    name="InputConfig",
    full_name="google.cloud.automl.v1.InputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.automl.v1.InputConfig.gcs_source",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1.InputConfig.params",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_INPUTCONFIG_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.automl.v1.InputConfig.source",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=129,
    serialized_end=321,
)


_BATCHPREDICTINPUTCONFIG = _descriptor.Descriptor(
    name="BatchPredictInputConfig",
    full_name="google.cloud.automl.v1.BatchPredictInputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.automl.v1.BatchPredictInputConfig.gcs_source",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.automl.v1.BatchPredictInputConfig.source",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=323,
    serialized_end=420,
)


_DOCUMENTINPUTCONFIG = _descriptor.Descriptor(
    name="DocumentInputConfig",
    full_name="google.cloud.automl.v1.DocumentInputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_source",
            full_name="google.cloud.automl.v1.DocumentInputConfig.gcs_source",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=422,
    serialized_end=498,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
    name="OutputConfig",
    full_name="google.cloud.automl.v1.OutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.automl.v1.OutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1.OutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=500,
    serialized_end=601,
)


_BATCHPREDICTOUTPUTCONFIG = _descriptor.Descriptor(
    name="BatchPredictOutputConfig",
    full_name="google.cloud.automl.v1.BatchPredictOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.automl.v1.BatchPredictOutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1.BatchPredictOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=603,
    serialized_end=716,
)


_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1.ModelExportOutputConfig.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.ModelExportOutputConfig.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.ModelExportOutputConfig.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=266,
    serialized_end=311,
)

_MODELEXPORTOUTPUTCONFIG = _descriptor.Descriptor(
    name="ModelExportOutputConfig",
    full_name="google.cloud.automl.v1.ModelExportOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.automl.v1.ModelExportOutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="model_format",
            full_name="google.cloud.automl.v1.ModelExportOutputConfig.model_format",
            index=1,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1.ModelExportOutputConfig.params",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.automl.v1.ModelExportOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=719,
    serialized_end=977,
)


_GCSSOURCE = _descriptor.Descriptor(
    name="GcsSource",
    full_name="google.cloud.automl.v1.GcsSource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="input_uris",
            full_name="google.cloud.automl.v1.GcsSource.input_uris",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=979,
    serialized_end=1015,
)


_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.automl.v1.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_uri_prefix",
            full_name="google.cloud.automl.v1.GcsDestination.output_uri_prefix",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1017,
    serialized_end=1065,
)

_INPUTCONFIG_PARAMSENTRY.containing_type = _INPUTCONFIG
_INPUTCONFIG.fields_by_name["gcs_source"].message_type = _GCSSOURCE
_INPUTCONFIG.fields_by_name["params"].message_type = _INPUTCONFIG_PARAMSENTRY
_INPUTCONFIG.oneofs_by_name["source"].fields.append(
    _INPUTCONFIG.fields_by_name["gcs_source"]
)
_INPUTCONFIG.fields_by_name[
    "gcs_source"
].containing_oneof = _INPUTCONFIG.oneofs_by_name["source"]
_BATCHPREDICTINPUTCONFIG.fields_by_name["gcs_source"].message_type = _GCSSOURCE
_BATCHPREDICTINPUTCONFIG.oneofs_by_name["source"].fields.append(
    _BATCHPREDICTINPUTCONFIG.fields_by_name["gcs_source"]
)
_BATCHPREDICTINPUTCONFIG.fields_by_name[
    "gcs_source"
].containing_oneof = _BATCHPREDICTINPUTCONFIG.oneofs_by_name["source"]
_DOCUMENTINPUTCONFIG.fields_by_name["gcs_source"].message_type = _GCSSOURCE
_OUTPUTCONFIG.fields_by_name["gcs_destination"].message_type = _GCSDESTINATION
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_BATCHPREDICTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].message_type = _GCSDESTINATION
_BATCHPREDICTOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _BATCHPREDICTOUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_BATCHPREDICTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _BATCHPREDICTOUTPUTCONFIG.oneofs_by_name["destination"]
_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY.containing_type = _MODELEXPORTOUTPUTCONFIG
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].message_type = _GCSDESTINATION
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "params"
].message_type = _MODELEXPORTOUTPUTCONFIG_PARAMSENTRY
_MODELEXPORTOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _MODELEXPORTOUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_MODELEXPORTOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _MODELEXPORTOUTPUTCONFIG.oneofs_by_name["destination"]
DESCRIPTOR.message_types_by_name["InputConfig"] = _INPUTCONFIG
DESCRIPTOR.message_types_by_name["BatchPredictInputConfig"] = _BATCHPREDICTINPUTCONFIG
DESCRIPTOR.message_types_by_name["DocumentInputConfig"] = _DOCUMENTINPUTCONFIG
DESCRIPTOR.message_types_by_name["OutputConfig"] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name["BatchPredictOutputConfig"] = _BATCHPREDICTOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["ModelExportOutputConfig"] = _MODELEXPORTOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["GcsSource"] = _GCSSOURCE
DESCRIPTOR.message_types_by_name["GcsDestination"] = _GCSDESTINATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputConfig = _reflection.GeneratedProtocolMessageType(
    "InputConfig",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_INPUTCONFIG_PARAMSENTRY,
                __module__="google.cloud.automl_v1.proto.io_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.InputConfig.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_INPUTCONFIG,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""Input configuration for
  [AutoMl.ImportData][google.cloud.automl.v1.AutoMl.ImportData] action.
  
  The format of input depends on dataset\_metadata the Dataset into which
  the import is happening has. As input source the
  [gcs\_source][google.cloud.automl.v1.InputConfig.gcs\_source] is
  expected, unless specified otherwise. Additionally any input .CSV file
  by itself must be 100MB or smaller, unless specified otherwise. If an
  "example" file (that is, image, video etc.) with identical content (even
  if it had different ``GCS_FILE_PATH``) is mentioned multiple times, then
  its label, bounding boxes etc. are appended. The same file should be
  always provided with the same ``ML_USE`` and ``GCS_FILE_PATH``, if it is
  not, then these values are nondeterministically selected from the given
  ones.
  
  The formats are represented in EBNF with commas being literal and with
  non-terminal symbols defined near the end of this comment. The formats
  are:
  
  
  
  
  
  See `Preparing your training
  data <https://cloud.google.com/vision/automl/docs/prepare>`__ for more
  information.
  
  CSV file(s) with each line in format:
  
  ::
  
      ML_USE,GCS_FILE_PATH,LABEL,LABEL,...
  
  -  ``ML_USE`` - Identifies the data set that the current row (file)
     applies to. This value can be one of the following:
  
     -  ``TRAIN`` - Rows in this file are used to train the model.
     -  ``TEST`` - Rows in this file are used to test the model during
        training.
     -  ``UNASSIGNED`` - Rows in this file are not categorized. They are
        Automatically divided into train and test data. 80% for training
        and 20% for testing.
  
  -  ``GCS_FILE_PATH`` - The Google Cloud Storage location of an image of
     up to 30MB in size. Supported extensions: .JPEG, .GIF, .PNG, .WEBP,
     .BMP, .TIFF, .ICO.
  
  -  ``LABEL`` - A label that identifies the object in the image.
  
  For the ``MULTICLASS`` classification type, at most one ``LABEL`` is
  allowed per image. If an image has not yet been labeled, then it should
  be mentioned just once with no ``LABEL``.
  
  Some sample rows:
  
  ::
  
      TRAIN,gs://folder/image1.jpg,daisy
      TEST,gs://folder/image2.jpg,dandelion,tulip,rose
      UNASSIGNED,gs://folder/image3.jpg,daisy
      UNASSIGNED,gs://folder/image4.jpg
  
  
  
  
  
  See `Preparing your training
  data <https://cloud.google.com/vision/automl/object-detection/docs/prepare>`__
  for more information.
  
  A CSV file(s) with each line in format:
  
  ::
  
      ML_USE,GCS_FILE_PATH,[LABEL],(BOUNDING_BOX | ,,,,,,,)
  
  -  ``ML_USE`` - Identifies the data set that the current row (file)
     applies to. This value can be one of the following:
  
     -  ``TRAIN`` - Rows in this file are used to train the model.
     -  ``TEST`` - Rows in this file are used to test the model during
        training.
     -  ``UNASSIGNED`` - Rows in this file are not categorized. They are
        Automatically divided into train and test data. 80% for training
        and 20% for testing.
  
  -  ``GCS_FILE_PATH`` - The Google Cloud Storage location of an image of
     up to 30MB in size. Supported extensions: .JPEG, .GIF, .PNG. Each
     image is assumed to be exhaustively labeled.
  
  -  ``LABEL`` - A label that identifies the object in the image specified
     by the ``BOUNDING_BOX``.
  
  -  ``BOUNDING BOX`` - The vertices of an object in the example image.
     The minimum allowed ``BOUNDING_BOX`` edge length is 0.01, and no more
     than 500 ``BOUNDING_BOX`` instances per image are allowed (one
     ``BOUNDING_BOX`` per line). If an image has no looked for objects
     then it should be mentioned just once with no LABEL and the ",,,,,,,"
     in place of the ``BOUNDING_BOX``.
  
  **Four sample rows:**
  
  ::
  
      TRAIN,gs://folder/image1.png,car,0.1,0.1,,,0.3,0.3,,
      TRAIN,gs://folder/image1.png,bike,.7,.6,,,.8,.9,,
      UNASSIGNED,gs://folder/im2.png,car,0.1,0.1,0.2,0.1,0.2,0.3,0.1,0.3
      TEST,gs://folder/im3.png,,,,,,,,,
  
  
  
  
  
  
  
  
  
  See `Preparing your training
  data </natural-language/automl/entity-analysis/docs/prepare>`__ for more
  information.
  
  One or more CSV file(s) with each line in the following format:
  
  ::
  
      ML_USE,GCS_FILE_PATH
  
  -  ``ML_USE`` - Identifies the data set that the current row (file)
     applies to. This value can be one of the following:
  
     -  ``TRAIN`` - Rows in this file are used to train the model.
     -  ``TEST`` - Rows in this file are used to test the model during
        training.
     -  ``UNASSIGNED`` - Rows in this file are not categorized. They are
        Automatically divided into train and test data. 80% for training
        and 20% for testing..
  
  -  ``GCS_FILE_PATH`` - a Identifies JSON Lines (.JSONL) file stored in
     Google Cloud Storage that contains in-line text in-line as documents
     for model training.
  
  After the training data set has been determined from the ``TRAIN`` and
  ``UNASSIGNED`` CSV files, the training data is divided into train and
  validation data sets. 70% for training and 30% for validation.
  
  For example:
  
  ::
  
      TRAIN,gs://folder/file1.jsonl
      VALIDATE,gs://folder/file2.jsonl
      TEST,gs://folder/file3.jsonl
  
  **In-line JSONL files**
  
  In-line .JSONL files contain, per line, a JSON document that wraps a
  [``text_snippet``][google.cloud.automl.v1.TextSnippet] field followed by
  one or more [``annotations``][google.cloud.automl.v1.AnnotationPayload]
  fields, which have ``display_name`` and ``text_extraction`` fields to
  describe the entity from the text snippet. Multiple JSON documents can
  be separated using line breaks (``\\n``).
  
  The supplied text must be annotated exhaustively. For example, if you
  include the text "horse", but do not label it as "animal", then "horse"
  is assumed to not be an "animal".
  
  Any given text snippet content must have 30,000 characters or less, and
  also be UTF-8 NFC encoded. ASCII is accepted as it is UTF-8 NFC encoded.
  
  For example:
  
  ::
  
      {
        "text_snippet": {
          "content": "dog car cat"
        },
        "annotations": [
           {
             "display_name": "animal",
             "text_extraction": {
               "text_segment": {"start_offset": 0, "end_offset": 2}
            }
           },
           {
            "display_name": "vehicle",
             "text_extraction": {
               "text_segment": {"start_offset": 4, "end_offset": 6}
             }
           },
           {
             "display_name": "animal",
             "text_extraction": {
               "text_segment": {"start_offset": 8, "end_offset": 10}
             }
           }
       ]
      }\\n
      {
         "text_snippet": {
           "content": "This dog is good."
         },
         "annotations": [
            {
              "display_name": "animal",
              "text_extraction": {
                "text_segment": {"start_offset": 5, "end_offset": 7}
              }
            }
         ]
      }
  
  **JSONL files that reference documents**
  
  .JSONL files contain, per line, a JSON document that wraps a
  ``input_config`` that contains the path to a source PDF document.
  Multiple JSON documents can be separated using line breaks
  (``\\n``).
  
  For example:
  
  ::
  
      {
        "document": {
          "input_config": {
            "gcs_source": { "input_uris": [ "gs://folder/document1.pdf" ]
            }
          }
        }
      }\\n
      {
        "document": {
          "input_config": {
            "gcs_source": { "input_uris": [ "gs://folder/document2.pdf" ]
            }
          }
        }
      }
  
  **In-line JSONL files with PDF layout information**
  
  **Note:** You can only annotate PDF files using the UI. The format
  described below applies to annotated PDF files exported using the UI or
  ``exportData``.
  
  In-line .JSONL files for PDF documents contain, per line, a JSON
  document that wraps a ``document`` field that provides the textual
  content of the PDF document and the layout information.
  
  For example:
  
  ::
  
      {
        "document": {
                "document_text": {
                  "content": "dog car cat"
                }
                "layout": [
                  {
                    "text_segment": {
                      "start_offset": 0,
                      "end_offset": 11,
                     },
                     "page_number": 1,
                     "bounding_poly": {
                        "normalized_vertices": [
                          {"x": 0.1, "y": 0.1},
                          {"x": 0.1, "y": 0.3},
                          {"x": 0.3, "y": 0.3},
                          {"x": 0.3, "y": 0.1},
                        ],
                      },
                      "text_segment_type": TOKEN,
                  }
                ],
                "document_dimensions": {
                  "width": 8.27,
                  "height": 11.69,
                  "unit": INCH,
                }
                "page_count": 3,
              },
              "annotations": [
                {
                  "display_name": "animal",
                  "text_extraction": {
                    "text_segment": {"start_offset": 0, "end_offset": 3}
                  }
                },
                {
                  "display_name": "vehicle",
                  "text_extraction": {
                    "text_segment": {"start_offset": 4, "end_offset": 7}
                  }
                },
                {
                  "display_name": "animal",
                  "text_extraction": {
                    "text_segment": {"start_offset": 8, "end_offset": 11}
                  }
                },
              ],
  
  
  
  
  
  See `Preparing your training
  data <https://cloud.google.com/natural-language/automl/docs/prepare>`__
  for more information.
  
  One or more CSV file(s) with each line in the following format:
  
  ::
  
      ML_USE,(TEXT_SNIPPET | GCS_FILE_PATH),LABEL,LABEL,...
  
  -  ``ML_USE`` - Identifies the data set that the current row (file)
     applies to. This value can be one of the following:
  
     -  ``TRAIN`` - Rows in this file are used to train the model.
     -  ``TEST`` - Rows in this file are used to test the model during
        training.
     -  ``UNASSIGNED`` - Rows in this file are not categorized. They are
        Automatically divided into train and test data. 80% for training
        and 20% for testing.
  
  -  ``TEXT_SNIPPET`` and ``GCS_FILE_PATH`` are distinguished by a
     pattern. If the column content is a valid Google Cloud Storage file
     path, that is, prefixed by "gs://", it is treated as a
     ``GCS_FILE_PATH``. Otherwise, if the content is enclosed in double
     quotes (""), it is treated as a ``TEXT_SNIPPET``. For
     ``GCS_FILE_PATH``, the path must lead to a file with supported
     extension and UTF-8 encoding, for example, "gs://folder/content.txt"
     AutoML imports the file content as a text snippet. For
     ``TEXT_SNIPPET``, AutoML imports the column content excluding quotes.
     In both cases, size of the content must be 10MB or less in size. For
     zip files, the size of each file inside the zip must be 10MB or less
     in size.
  
     For the ``MULTICLASS`` classification type, at most one ``LABEL`` is
     allowed. The ``ML_USE`` and ``LABEL`` columns are optional. Supported
     file extensions: .TXT, .PDF, .ZIP
  
  A maximum of 100 unique labels are allowed per CSV row.
  
  Sample rows:
  
  ::
  
      TRAIN,"They have bad food and very rude",RudeService,BadFood
      gs://folder/content.txt,SlowService
      TEST,gs://folder/document.pdf
      VALIDATE,gs://folder/text_files.zip,BadFood
  
  
  
  
  
  See `Preparing your training
  data <https://cloud.google.com/natural-language/automl/docs/prepare>`__
  for more information.
  
  CSV file(s) with each line in format:
  
  ::
  
      ML_USE,(TEXT_SNIPPET | GCS_FILE_PATH),SENTIMENT
  
  -  ``ML_USE`` - Identifies the data set that the current row (file)
     applies to. This value can be one of the following:
  
     -  ``TRAIN`` - Rows in this file are used to train the model.
     -  ``TEST`` - Rows in this file are used to test the model during
        training.
     -  ``UNASSIGNED`` - Rows in this file are not categorized. They are
        Automatically divided into train and test data. 80% for training
        and 20% for testing.
  
  -  ``TEXT_SNIPPET`` and ``GCS_FILE_PATH`` are distinguished by a
     pattern. If the column content is a valid Google Cloud Storage file
     path, that is, prefixed by "gs://", it is treated as a
     ``GCS_FILE_PATH``. Otherwise, if the content is enclosed in double
     quotes (""), it is treated as a ``TEXT_SNIPPET``. For
     ``GCS_FILE_PATH``, the path must lead to a file with supported
     extension and UTF-8 encoding, for example, "gs://folder/content.txt"
     AutoML imports the file content as a text snippet. For
     ``TEXT_SNIPPET``, AutoML imports the column content excluding quotes.
     In both cases, size of the content must be 128kB or less in size. For
     zip files, the size of each file inside the zip must be 128kB or less
     in size.
  
     The ``ML_USE`` and ``SENTIMENT`` columns are optional. Supported file
     extensions: .TXT, .PDF, .ZIP
  
  -  ``SENTIMENT`` - An integer between 0 and
     Dataset.text\_sentiment\_dataset\_metadata.sentiment\_max
     (inclusive). Describes the ordinal of the sentiment - higher value
     means a more positive sentiment. All the values are completely
     relative, i.e. neither 0 needs to mean a negative or neutral
     sentiment nor sentiment\_max needs to mean a positive one - it is
     just required that 0 is the least positive sentiment in the data, and
     sentiment\_max is the most positive one. The SENTIMENT shouldn't be
     confused with "score" or "magnitude" from the previous Natural
     Language Sentiment Analysis API. All SENTIMENT values between 0 and
     sentiment\_max must be represented in the imported data. On
     prediction the same 0 to sentiment\_max range will be used. The
     difference between neighboring sentiment values needs not to be
     uniform, e.g. 1 and 2 may be similar whereas the difference between 2
     and 3 may be large.
  
  Sample rows:
  
  ::
  
      TRAIN,"@freewrytin this is way too good for your product",2
      gs://folder/content.txt,3
      TEST,gs://folder/document.pdf
      VALIDATE,gs://folder/text_files.zip,2
  
  
  
  
  
  **Input field definitions:**
  
  ``ML_USE``
      ("TRAIN" \| "VALIDATE" \| "TEST" \| "UNASSIGNED") Describes how the
      given example (file) should be used for model training. "UNASSIGNED"
      can be used when user has no preference.
  ``GCS_FILE_PATH``
      The path to a file on Google Cloud Storage. For example,
      "gs://folder/image1.png".
  ``LABEL``
      A display name of an object on an image, video etc., e.g. "dog".
      Must be up to 32 characters long and can consist only of ASCII Latin
      letters A-Z and a-z, underscores(\_), and ASCII digits 0-9. For each
      label an AnnotationSpec is created which display\_name becomes the
      label; AnnotationSpecs are given back in predictions.
  ``BOUNDING_BOX``
      (``VERTEX,VERTEX,VERTEX,VERTEX`` \| ``VERTEX,,,VERTEX,,``) A
      rectangle parallel to the frame of the example (image, video). If 4
      vertices are given they are connected by edges in the order
      provided, if 2 are given they are recognized as diagonally opposite
      vertices of the rectangle.
  ``VERTEX``
      (``COORDINATE,COORDINATE``) First coordinate is horizontal (x), the
      second is vertical (y).
  ``COORDINATE``
      A float in 0 to 1 range, relative to total length of image or video
      in given dimension. For fractions the leading non-decimal 0 can be
      omitted (i.e. 0.3 = .3). Point 0,0 is in top left.
  ``TEXT_SNIPPET``
      The content of a text snippet, UTF-8 encoded, enclosed within double
      quotes ("").
  ``DOCUMENT``
      A field that provides the textual content with document and the
      layout information.
  
  **Errors:**
  
  If any of the provided CSV files can't be parsed or if more than certain
  percent of CSV rows cannot be processed then the operation fails and
  nothing is imported. Regardless of overall success or failure the
  per-row failures, up to a certain count cap, is listed in
  Operation.metadata.partial\_failures.
  
  
  Attributes:
      source:
          The source of the input.
      gcs_source:
          The Google Cloud Storage location for the input content. For
          [AutoMl.ImportData][google.cloud.automl.v1.AutoMl.ImportData],
          ``gcs_source`` points to a CSV file with a structure described
          in [InputConfig][google.cloud.automl.v1.InputConfig].
      params:
          Additional domain-specific parameters describing the semantic
          of the imported data, any string must be up to 25000
          characters long.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.InputConfig)
    ),
)
_sym_db.RegisterMessage(InputConfig)
_sym_db.RegisterMessage(InputConfig.ParamsEntry)

BatchPredictInputConfig = _reflection.GeneratedProtocolMessageType(
    "BatchPredictInputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHPREDICTINPUTCONFIG,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""Input configuration for BatchPredict Action.
  
  The format of input depends on the ML problem of the model used for
  prediction. As input source the
  [gcs\_source][google.cloud.automl.v1.InputConfig.gcs\_source] is
  expected, unless specified otherwise.
  
  The formats are represented in EBNF with commas being literal and with
  non-terminal symbols defined near the end of this comment. The formats
  are:
  
  
  
  
  
  One or more CSV files where each line is a single column:
  
  ::
  
      GCS_FILE_PATH
  
  ``GCS_FILE_PATH`` is the Google Cloud Storage location of a text file.
  Supported file extensions: .TXT, .PDF Text files can be no larger than
  10MB in size.
  
  Sample rows:
  
  ::
  
      gs://folder/text1.txt
      gs://folder/text2.pdf
  
  
  
  
  
  One or more CSV files where each line is a single column:
  
  ::
  
      GCS_FILE_PATH
  
  ``GCS_FILE_PATH`` is the Google Cloud Storage location of a text file.
  Supported file extensions: .TXT, .PDF Text files can be no larger than
  128kB in size.
  
  Sample rows:
  
  ::
  
      gs://folder/text1.txt
      gs://folder/text2.pdf
  
  
  
  
  
  One or more JSONL (JSON Lines) files that either provide inline text or
  documents. You can only use one format, either inline text or documents,
  for a single call to [AutoMl.BatchPredict].
  
  Each JSONL file contains a per line a proto that wraps a temporary
  user-assigned TextSnippet ID (string up to 2000 characters long) called
  "id", a TextSnippet proto (in JSON representation) and zero or more
  TextFeature protos. Any given text snippet content must have 30,000
  characters or less, and also be UTF-8 NFC encoded (ASCII already is).
  The IDs provided should be unique.
  
  Each document JSONL file contains, per line, a proto that wraps a
  Document proto with ``input_config`` set. Only PDF documents are
  currently supported, and each PDF document cannot exceed 2MB in size.
  
  Each JSONL file must not exceed 100MB in size, and no more than 20 JSONL
  files may be passed.
  
  Sample inline JSONL file (Shown with artificial line breaks. Actual line
  breaks are denoted by "``\\n``".):
  
  ::
  
      {
         "id": "my_first_id",
         "text_snippet": { "content": "dog car cat"},
         "text_features": [
           {
             "text_segment": {"start_offset": 4, "end_offset": 6},
             "structural_type": PARAGRAPH,
             "bounding_poly": {
               "normalized_vertices": [
                 {"x": 0.1, "y": 0.1},
                 {"x": 0.1, "y": 0.3},
                 {"x": 0.3, "y": 0.3},
                 {"x": 0.3, "y": 0.1},
               ]
             },
           }
         ],
       }\\n
       {
         "id": "2",
         "text_snippet": {
           "content": "Extended sample content",
           "mime_type": "text/plain"
         }
       }
  
  Sample document JSONL file (Shown with artificial line breaks. Actual
  line breaks are denoted by "``\\n``".):
  
  ::
  
       {
         "document": {
           "input_config": {
             "gcs_source": { "input_uris": [ "gs://folder/document1.pdf" ]
             }
           }
         }
       }\\n
       {
         "document": {
           "input_config": {
             "gcs_source": { "input_uris": [ "gs://folder/document2.pdf" ]
             }
           }
         }
       }
  
  
  
  
  
  **Input field definitions:**
  
  ``GCS_FILE_PATH``
      The path to a file on Google Cloud Storage. For example,
      "gs://folder/video.avi".
  
  **Errors:**
  
  If any of the provided CSV files can't be parsed or if more than certain
  percent of CSV rows cannot be processed then the operation fails and
  prediction does not happen. Regardless of overall success or failure the
  per-row failures, up to a certain count cap, will be listed in
  Operation.metadata.partial\_failures.
  
  
  Attributes:
      source:
          The source of the input.
      gcs_source:
          Required. The Google Cloud Storage location for the input
          content.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.BatchPredictInputConfig)
    ),
)
_sym_db.RegisterMessage(BatchPredictInputConfig)

DocumentInputConfig = _reflection.GeneratedProtocolMessageType(
    "DocumentInputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DOCUMENTINPUTCONFIG,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""Input configuration of a
  [Document][google.cloud.automl.v1.Document].
  
  
  Attributes:
      gcs_source:
          The Google Cloud Storage location of the document file. Only a
          single path should be given.  Max supported size: 512MB.
          Supported extensions: .PDF.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.DocumentInputConfig)
    ),
)
_sym_db.RegisterMessage(DocumentInputConfig)

OutputConfig = _reflection.GeneratedProtocolMessageType(
    "OutputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_OUTPUTCONFIG,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""Output configuration for ExportData.
  
  As destination the
  [gcs\_destination][google.cloud.automl.v1.OutputConfig.gcs\_destination]
  must be set unless specified otherwise for a domain. If gcs\_destination
  is set then in the given directory a new directory is created. Its name
  will be "export\_data--", where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ
  ISO-8601 format. Only ground truth annotations are exported (not
  approved annotations are not exported).
  
  The outputs correspond to how the data was imported, and may be used as
  input to import data. The output formats are represented as EBNF with
  literal commas and same non-terminal symbols definitions are these in
  import data's [InputConfig][google.cloud.automl.v1.InputConfig]:
  
  -  For Image Classification: CSV file(s) ``image_classification_1.csv``,
     ``image_classification_2.csv``,...,\ ``image_classification_N.csv``\ with
     each line in format: ML\_USE,GCS\_FILE\_PATH,LABEL,LABEL,... where
     GCS\_FILE\_PATHs point at the original, source locations of the
     imported images. For MULTICLASS classification type, there can be at
     most one LABEL per example.
  
  -  For Image Object Detection: CSV file(s)
     ``image_object_detection_1.csv``,
     ``image_object_detection_2.csv``,...,\ ``image_object_detection_N.csv``
     with each line in format:
     ML\_USE,GCS\_FILE\_PATH,[LABEL],(BOUNDING\_BOX \| ,,,,,,,) where
     GCS\_FILE\_PATHs point at the original, source locations of the
     imported images.
  
  -  For Text Classification: In the created directory CSV file(s)
     ``text_classification_1.csv``, ``text_classification_2.csv``,
     ...,\ ``text_classification_N.csv`` will be created where N depends
     on the total number of examples exported. Each line in the CSV is of
     the format: ML\_USE,GCS\_FILE\_PATH,LABEL,LABEL,... where
     GCS\_FILE\_PATHs point at the exported .txt files containing the text
     content of the imported example. For MULTICLASS classification type,
     there will be at most one LABEL per example.
  
  -  For Text Sentiment: In the created directory CSV file(s)
     ``text_sentiment_1.csv``, ``text_sentiment_2.csv``,
     ...,\ ``text_sentiment_N.csv`` will be created where N depends on the
     total number of examples exported. Each line in the CSV is of the
     format: ML\_USE,GCS\_FILE\_PATH,SENTIMENT where GCS\_FILE\_PATHs
     point at the exported .txt files containing the text content of the
     imported example.
  
  -  For Text Extraction: CSV file ``text_extraction.csv``, with each line
     in format: ML\_USE,GCS\_FILE\_PATH GCS\_FILE\_PATH leads to a .JSONL
     (i.e. JSON Lines) file which contains, per line, a proto that wraps a
     TextSnippet proto (in json representation) followed by
     AnnotationPayload protos (called annotations). If initially documents
     had been imported, the JSONL will point at the original, source
     locations of the imported documents.
  
  -  For Translation: CSV file ``translation.csv``, with each line in
     format: ML\_USE,GCS\_FILE\_PATH GCS\_FILE\_PATH leads to a .TSV file
     which describes examples that have given ML\_USE, using the following
     row format per line: TEXT\_SNIPPET (in source language)
     \\tTEXT\_SNIPPET (in target language)
  
  
  Attributes:
      destination:
          The destination of the output.
      gcs_destination:
          Required. The Google Cloud Storage location where the output
          is to be written to. For Image Object Detection, Text
          Extraction in the given directory a new directory will be
          created with name: export\_data-- where timestamp is in YYYY-
          MM-DDThh:mm:ss.sssZ ISO-8601 format. All export output will be
          written into that directory.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.OutputConfig)
    ),
)
_sym_db.RegisterMessage(OutputConfig)

BatchPredictOutputConfig = _reflection.GeneratedProtocolMessageType(
    "BatchPredictOutputConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHPREDICTOUTPUTCONFIG,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""Output configuration for BatchPredict Action.
  
  As destination the
  
  [gcs\_destination][google.cloud.automl.v1.BatchPredictOutputConfig.gcs\_destination]
  must be set unless specified otherwise for a domain. If gcs\_destination
  is set then in the given directory a new directory is created. Its name
  will be "prediction--", where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ
  ISO-8601 format. The contents of it depends on the ML problem the
  predictions are made for.
  
  -  For Text Classification: In the created directory files
     ``text_classification_1.jsonl``,
     ``text_classification_2.jsonl``,...,\ ``text_classification_N.jsonl``
     will be created, where N may be 1, and depends on the total number of
     inputs and annotations found.
  
     ::
  
         Each .JSONL file will contain, per line, a JSON representation of a
         proto that wraps input text (or pdf) file in
         the text snippet (or document) proto and a list of
         zero or more AnnotationPayload protos (called annotations), which
         have classification detail populated. A single text (or pdf) file
         will be listed only once with all its annotations, and its
         annotations will never be split across files.
  
         If prediction for any text (or pdf) file failed (partially or
         completely), then additional `errors_1.jsonl`, `errors_2.jsonl`,...,
         `errors_N.jsonl` files will be created (N depends on total number of
         failed predictions). These files will have a JSON representation of a
         proto that wraps input text (or pdf) file followed by exactly one
  
  ```google.rpc.Status`` <https:%20//github.com/googleapis/googleapis/blob/master/google/rpc/status.proto>`__
  containing only ``code`` and ``message``.
  
  -  For Text Sentiment: In the created directory files
     ``text_sentiment_1.jsonl``,
     ``text_sentiment_2.jsonl``,...,\ ``text_sentiment_N.jsonl`` will be
     created, where N may be 1, and depends on the total number of inputs
     and annotations found.
  
     ::
  
         Each .JSONL file will contain, per line, a JSON representation of a
         proto that wraps input text (or pdf) file in
         the text snippet (or document) proto and a list of
         zero or more AnnotationPayload protos (called annotations), which
         have text_sentiment detail populated. A single text (or pdf) file
         will be listed only once with all its annotations, and its
         annotations will never be split across files.
  
         If prediction for any text (or pdf) file failed (partially or
         completely), then additional `errors_1.jsonl`, `errors_2.jsonl`,...,
         `errors_N.jsonl` files will be created (N depends on total number of
         failed predictions). These files will have a JSON representation of a
         proto that wraps input text (or pdf) file followed by exactly one
  
  ```google.rpc.Status`` <https:%20//github.com/googleapis/googleapis/blob/master/google/rpc/status.proto>`__
  containing only ``code`` and ``message``.
  
  -  For Text Extraction: In the created directory files
     ``text_extraction_1.jsonl``,
     ``text_extraction_2.jsonl``,...,\ ``text_extraction_N.jsonl`` will be
     created, where N may be 1, and depends on the total number of inputs
     and annotations found. The contents of these .JSONL file(s) depend on
     whether the input used inline text, or documents. If input was
     inline, then each .JSONL file will contain, per line, a JSON
     representation of a proto that wraps given in request text snippet's
     "id" (if specified), followed by input text snippet, and a list of
     zero or more AnnotationPayload protos (called annotations), which
     have text\_extraction detail populated. A single text snippet will be
     listed only once with all its annotations, and its annotations will
     never be split across files. If input used documents, then each
     .JSONL file will contain, per line, a JSON representation of a proto
     that wraps given in request document proto, followed by its OCR-ed
     representation in the form of a text snippet, finally followed by a
     list of zero or more AnnotationPayload protos (called annotations),
     which have text\_extraction detail populated and refer, via their
     indices, to the OCR-ed text snippet. A single document (and its text
     snippet) will be listed only once with all its annotations, and its
     annotations will never be split across files. If prediction for any
     text snippet failed (partially or completely), then additional
     ``errors_1.jsonl``, ``errors_2.jsonl``,..., ``errors_N.jsonl`` files
     will be created (N depends on total number of failed predictions).
     These files will have a JSON representation of a proto that wraps
     either the "id" : "" (in case of inline) or the document proto (in
     case of document) but here followed by exactly one
     ```google.rpc.Status`` <https:%20//github.com/googleapis/googleapis/blob/master/google/rpc/status.proto>`__
     containing only ``code`` and ``message``.
  
  
  Attributes:
      destination:
          The destination of the output.
      gcs_destination:
          Required. The Google Cloud Storage location of the directory
          where the output is to be written to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.BatchPredictOutputConfig)
    ),
)
_sym_db.RegisterMessage(BatchPredictOutputConfig)

ModelExportOutputConfig = _reflection.GeneratedProtocolMessageType(
    "ModelExportOutputConfig",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY,
                __module__="google.cloud.automl_v1.proto.io_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ModelExportOutputConfig.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_MODELEXPORTOUTPUTCONFIG,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""Output configuration for ModelExport Action.
  
  
  Attributes:
      destination:
          The destination of the output.
      gcs_destination:
          Required. The Google Cloud Storage location where the model is
          to be written to. This location may only be set for the
          following model formats: "tflite", "edgetpu\_tflite",
          "tf\_saved\_model", "tf\_js", "core\_ml".  Under the directory
          given as the destination a new one with name "model-export--",
          where timestamp is in YYYY-MM-DDThh:mm:ss.sssZ ISO-8601
          format, will be created. Inside the model and any of its
          supporting files will be written.
      model_format:
          The format in which the model must be exported. The available,
          and default, formats depend on the problem and model type (if
          given problem and type combination doesn't have a format
          listed, it means its models are not exportable):  -  For Image
          Classification mobile-low-latency-1, mobile-versatile-1,
          mobile-high-accuracy-1: "tflite" (default), "edgetpu\_tflite",
          "tf\_saved\_model", "tf\_js".  -  For Image Classification
          mobile-core-ml-low-latency-1,    mobile-core-ml-versatile-1,
          mobile-core-ml-high-accuracy-1:    "core\_ml" (default).  -
          For Image Object Detection mobile-low-latency-1, mobile-
          versatile-1,    mobile-high-accuracy-1: "tflite",
          "tf\_saved\_model", "tf\_js".    Formats description:  -
          tflite - Used for Android mobile devices. -  edgetpu\_tflite -
          Used for `Edge    TPU <https://cloud.google.com/edge-tpu/>`__
          devices. -  tf\_saved\_model - A tensorflow model in
          SavedModel format. -  tf\_js - A `TensorFlow.js
          <https://www.tensorflow.org/js>`__ model    that can be used
          in the browser and in Node.js using JavaScript.x\` -  core\_ml
          - Used for iOS mobile devices.
      params:
          Additional model-type and format specific parameters
          describing the requirements for the to be exported model
          files, any string must be up to 25000 characters long.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ModelExportOutputConfig)
    ),
)
_sym_db.RegisterMessage(ModelExportOutputConfig)
_sym_db.RegisterMessage(ModelExportOutputConfig.ParamsEntry)

GcsSource = _reflection.GeneratedProtocolMessageType(
    "GcsSource",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GCSSOURCE,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""The Google Cloud Storage location for the input content.
  
  
  Attributes:
      input_uris:
          Required. Google Cloud Storage URIs to input files, up to 2000
          characters long. Accepted forms: \* Full object path, e.g.
          gs://bucket/directory/object.csv
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.GcsSource)
    ),
)
_sym_db.RegisterMessage(GcsSource)

GcsDestination = _reflection.GeneratedProtocolMessageType(
    "GcsDestination",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GCSDESTINATION,
        __module__="google.cloud.automl_v1.proto.io_pb2",
        __doc__="""The Google Cloud Storage location where the output is to
  be written to.
  
  
  Attributes:
      output_uri_prefix:
          Required. Google Cloud Storage URI to output directory, up to
          2000 characters long. Accepted forms: \* Prefix path:
          gs://bucket/directory The requesting user must have write
          permission to the bucket. The directory is created if it
          doesn't exist.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.GcsDestination)
    ),
)
_sym_db.RegisterMessage(GcsDestination)


DESCRIPTOR._options = None
_INPUTCONFIG_PARAMSENTRY._options = None
_BATCHPREDICTINPUTCONFIG.fields_by_name["gcs_source"]._options = None
_OUTPUTCONFIG.fields_by_name["gcs_destination"]._options = None
_BATCHPREDICTOUTPUTCONFIG.fields_by_name["gcs_destination"]._options = None
_MODELEXPORTOUTPUTCONFIG_PARAMSENTRY._options = None
_MODELEXPORTOUTPUTCONFIG.fields_by_name["gcs_destination"]._options = None
_GCSSOURCE.fields_by_name["input_uris"]._options = None
_GCSDESTINATION.fields_by_name["output_uri_prefix"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1/proto/model.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.automl_v1.proto import (
    image_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2,
)
from google.cloud.automl_v1.proto import (
    text_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2,
)
from google.cloud.automl_v1.proto import (
    translation_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_translation__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1/proto/model.proto",
    package="google.cloud.automl.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\032com.google.cloud.automl.v1P\001Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\252\002\026Google.Cloud.AutoML.V1\312\002\026Google\\Cloud\\AutoMl\\V1\352\002\031Google::Cloud::AutoML::V1"
    ),
    serialized_pb=_b(
        '\n(google/cloud/automl_v1/proto/model.proto\x12\x16google.cloud.automl.v1\x1a\x19google/api/resource.proto\x1a(google/cloud/automl_v1/proto/image.proto\x1a\'google/cloud/automl_v1/proto/text.proto\x1a.google/cloud/automl_v1/proto/translation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto"\xfa\x08\n\x05Model\x12V\n\x1atranslation_model_metadata\x18\x0f \x01(\x0b\x32\x30.google.cloud.automl.v1.TranslationModelMetadataH\x00\x12g\n#image_classification_model_metadata\x18\r \x01(\x0b\x32\x38.google.cloud.automl.v1.ImageClassificationModelMetadataH\x00\x12\x65\n"text_classification_model_metadata\x18\x0e \x01(\x0b\x32\x37.google.cloud.automl.v1.TextClassificationModelMetadataH\x00\x12j\n%image_object_detection_model_metadata\x18\x14 \x01(\x0b\x32\x39.google.cloud.automl.v1.ImageObjectDetectionModelMetadataH\x00\x12]\n\x1etext_extraction_model_metadata\x18\x13 \x01(\x0b\x32\x33.google.cloud.automl.v1.TextExtractionModelMetadataH\x00\x12[\n\x1dtext_sentiment_model_metadata\x18\x16 \x01(\x0b\x32\x32.google.cloud.automl.v1.TextSentimentModelMetadataH\x00\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x12\n\ndataset_id\x18\x03 \x01(\t\x12/\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x10\x64\x65ployment_state\x18\x08 \x01(\x0e\x32-.google.cloud.automl.v1.Model.DeploymentState\x12\x0c\n\x04\x65tag\x18\n \x01(\t\x12\x39\n\x06labels\x18" \x03(\x0b\x32).google.cloud.automl.v1.Model.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"Q\n\x0f\x44\x65ploymentState\x12 \n\x1c\x44\x45PLOYMENT_STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44\x45PLOYED\x10\x01\x12\x0e\n\nUNDEPLOYED\x10\x02:a\xea\x41^\n\x1b\x61utoml.googleapis.com/Model\x12?projects/{project_id}/locations/{location_id}/models/{model_id}B\x10\n\x0emodel_metadataB\xaa\x01\n\x1a\x63om.google.cloud.automl.v1P\x01Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\xaa\x02\x16Google.Cloud.AutoML.V1\xca\x02\x16Google\\Cloud\\AutoMl\\V1\xea\x02\x19Google::Cloud::AutoML::V1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_translation__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_MODEL_DEPLOYMENTSTATE = _descriptor.EnumDescriptor(
    name="DeploymentState",
    full_name="google.cloud.automl.v1.Model.DeploymentState",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DEPLOYMENT_STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="DEPLOYED", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="UNDEPLOYED", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1238,
    serialized_end=1319,
)
_sym_db.RegisterEnumDescriptor(_MODEL_DEPLOYMENTSTATE)


_MODEL_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="google.cloud.automl.v1.Model.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1.Model.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1.Model.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1191,
    serialized_end=1236,
)

_MODEL = _descriptor.Descriptor(
    name="Model",
    full_name="google.cloud.automl.v1.Model",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="translation_model_metadata",
            full_name="google.cloud.automl.v1.Model.translation_model_metadata",
            index=0,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_classification_model_metadata",
            full_name="google.cloud.automl.v1.Model.image_classification_model_metadata",
            index=1,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_classification_model_metadata",
            full_name="google.cloud.automl.v1.Model.text_classification_model_metadata",
            index=2,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_object_detection_model_metadata",
            full_name="google.cloud.automl.v1.Model.image_object_detection_model_metadata",
            index=3,
            number=20,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_extraction_model_metadata",
            full_name="google.cloud.automl.v1.Model.text_extraction_model_metadata",
            index=4,
            number=19,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_sentiment_model_metadata",
            full_name="google.cloud.automl.v1.Model.text_sentiment_model_metadata",
            index=5,
            number=22,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.Model.name",
            index=6,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.automl.v1.Model.display_name",
            index=7,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="dataset_id",
            full_name="google.cloud.automl.v1.Model.dataset_id",
            index=8,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.automl.v1.Model.create_time",
            index=9,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.automl.v1.Model.update_time",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="deployment_state",
            full_name="google.cloud.automl.v1.Model.deployment_state",
            index=11,
            number=8,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="etag",
            full_name="google.cloud.automl.v1.Model.etag",
            index=12,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="google.cloud.automl.v1.Model.labels",
            index=13,
            number=34,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_MODEL_LABELSENTRY],
    enum_types=[_MODEL_DEPLOYMENTSTATE],
    serialized_options=_b(
        "\352A^\n\033automl.googleapis.com/Model\022?projects/{project_id}/locations/{location_id}/models/{model_id}"
    ),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="model_metadata",
            full_name="google.cloud.automl.v1.Model.model_metadata",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=290,
    serialized_end=1436,
)

_MODEL_LABELSENTRY.containing_type = _MODEL
_MODEL.fields_by_name[
    "translation_model_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_translation__pb2._TRANSLATIONMODELMETADATA
)
_MODEL.fields_by_name[
    "image_classification_model_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2._IMAGECLASSIFICATIONMODELMETADATA
)
_MODEL.fields_by_name[
    "text_classification_model_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2._TEXTCLASSIFICATIONMODELMETADATA
)
_MODEL.fields_by_name[
    "image_object_detection_model_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2._IMAGEOBJECTDETECTIONMODELMETADATA
)
_MODEL.fields_by_name[
    "text_extraction_model_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2._TEXTEXTRACTIONMODELMETADATA
)
_MODEL.fields_by_name[
    "text_sentiment_model_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_text__pb2._TEXTSENTIMENTMODELMETADATA
)
_MODEL.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODEL.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODEL.fields_by_name["deployment_state"].enum_type = _MODEL_DEPLOYMENTSTATE
_MODEL.fields_by_name["labels"].message_type = _MODEL_LABELSENTRY
_MODEL_DEPLOYMENTSTATE.containing_type = _MODEL
_MODEL.oneofs_by_name["model_metadata"].fields.append(
    _MODEL.fields_by_name["translation_model_metadata"]
)
_MODEL.fields_by_name[
    "translation_model_metadata"
].containing_oneof = _MODEL.oneofs_by_name["model_metadata"]
_MODEL.oneofs_by_name["model_metadata"].fields.append(
    _MODEL.fields_by_name["image_classification_model_metadata"]
)
_MODEL.fields_by_name[
    "image_classification_model_metadata"
].containing_oneof = _MODEL.oneofs_by_name["model_metadata"]
_MODEL.oneofs_by_name["model_metadata"].fields.append(
    _MODEL.fields_by_name["text_classification_model_metadata"]
)
_MODEL.fields_by_name[
    "text_classification_model_metadata"
].containing_oneof = _MODEL.oneofs_by_name["model_metadata"]
_MODEL.oneofs_by_name["model_metadata"].fields.append(
    _MODEL.fields_by_name["image_object_detection_model_metadata"]
)
_MODEL.fields_by_name[
    "image_object_detection_model_metadata"
].containing_oneof = _MODEL.oneofs_by_name["model_metadata"]
_MODEL.oneofs_by_name["model_metadata"].fields.append(
    _MODEL.fields_by_name["text_extraction_model_metadata"]
)
_MODEL.fields_by_name[
    "text_extraction_model_metadata"
].containing_oneof = _MODEL.oneofs_by_name["model_metadata"]
_MODEL.oneofs_by_name["model_metadata"].fields.append(
    _MODEL.fields_by_name["text_sentiment_model_metadata"]
)
_MODEL.fields_by_name[
    "text_sentiment_model_metadata"
].containing_oneof = _MODEL.oneofs_by_name["model_metadata"]
DESCRIPTOR.message_types_by_name["Model"] = _MODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Model = _reflection.GeneratedProtocolMessageType(
    "Model",
    (_message.Message,),
    dict(
        LabelsEntry=_reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_MODEL_LABELSENTRY,
                __module__="google.cloud.automl_v1.proto.model_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.Model.LabelsEntry)
            ),
        ),
        DESCRIPTOR=_MODEL,
        __module__="google.cloud.automl_v1.proto.model_pb2",
        __doc__="""API proto representing a trained machine learning model.
  
  
  Attributes:
      model_metadata:
          Required. The model metadata that is specific to the problem
          type. Must match the metadata type of the dataset used to
          train the model.
      translation_model_metadata:
          Metadata for translation models.
      image_classification_model_metadata:
          Metadata for image classification models.
      text_classification_model_metadata:
          Metadata for text classification models.
      image_object_detection_model_metadata:
          Metadata for image object detection models.
      text_extraction_model_metadata:
          Metadata for text extraction models.
      text_sentiment_model_metadata:
          Metadata for text sentiment models.
      name:
          Output only. Resource name of the model. Format: ``projects/{p
          roject_id}/locations/{location_id}/models/{model_id}``
      display_name:
          Required. The name of the model to show in the interface. The
          name can be up to 32 characters long and can consist only of
          ASCII Latin letters A-Z and a-z, underscores (\_), and ASCII
          digits 0-9. It must start with a letter.
      dataset_id:
          Required. The resource ID of the dataset used to create the
          model. The dataset must come from the same ancestor project
          and location.
      create_time:
          Output only. Timestamp when the model training finished and
          can be used for prediction.
      update_time:
          Output only. Timestamp when this model was last updated.
      deployment_state:
          Output only. Deployment state of the model. A model can only
          serve prediction requests after it gets deployed.
      etag:
          Used to perform a consistent read-modify-write updates. If not
          set, a blind "overwrite" update happens.
      labels:
          Optional. The labels with user-defined metadata to organize
          your model.  Label keys and values can be no longer than 64
          characters (Unicode codepoints), can only contain lowercase
          letters, numeric characters, underscores and dashes.
          International characters are allowed. Label values are
          optional. Label keys must start with a letter.  See
          https://goo.gl/xmQnxf for more information on and examples of
          labels.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.Model)
    ),
)
_sym_db.RegisterMessage(Model)
_sym_db.RegisterMessage(Model.LabelsEntry)


DESCRIPTOR._options = None
_MODEL_LABELSENTRY._options = None
_MODEL._options = None
# @@protoc_insertion_point(module_scope)
